@@ -1,5 +1,5 @@
 from google.protobuf import timestamp_pb2
-from cap.pb.coretex.agent.v1 import buspacket_pb2
+from cap.pb.cordum.agent.v1 import buspacket_pb2
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.hazmat.primitives import hashes
 from typing import Optional
